@@ -32,7 +32,7 @@ class SessionHandler():
   def get_or_create(self,session, obj):
     keys = [key.name for key in inspect(obj.__class__).primary_key]
     key_values = {k: v for k, v in obj.__dict__.items() if v and k in keys}
-    params = {k: v for k, v in obj.__dict__.items() if v and k.startswith("_") == False}
+    params = {k: v for k, v in obj.__dict__.items() if v and k.startswith("_") == False and k not in keys}
     instance = session.query(obj.__class__).filter_by(**key_values).first()
     if instance:
       instance.update(**params)
